pub enum OciRef {
LocalStorage(Reference),
OciArchive(PathBuf),
OciDir(PathBuf),
Remote(Reference),
}Variants
Implementations
Sourceimpl OciRef
impl OciRef
pub fn from_local_storage(local_ref: &Reference) -> Self
Sourcepub fn from_oci_archive<P: AsRef<Path>>(path: P) -> Result<Self, Report>
pub fn from_oci_archive<P: AsRef<Path>>(path: P) -> Result<Self, Report>
Errors
Returns an error if the path does not point to a regular file.
Sourcepub fn from_oci_directory<P: AsRef<Path>>(path: P) -> Result<Self, Report>
pub fn from_oci_directory<P: AsRef<Path>>(path: P) -> Result<Self, Report>
Errors
Returns an error if the path does not point to a directory.
pub fn from_remote_ref(image_ref: &Reference) -> Self
pub fn to_os_string(&self) -> OsString