Credentials

Enum Credentials 

pub enum Credentials {
    Basic {
        username: String,
        password: SecretValue,
    },
    Token(SecretValue),
}
The credentials for logging into image registries.

Variants



Basic

Fields

username: String
password: SecretValue


Token(SecretValue)

Implementations

Source

impl Credentials

pub fn init(args: CredentialsArgs)

Set the users credentials for the current set of actions.

Be sure to call this before trying to use any strategy that requires credentials as the environment credentials are lazy allocated.

Panics

Will panic if it can’t lock the mutex.

pub fn get(registry: &str) -> Option<Self>

Get the credentials for the current set of actions.

Panics

Will panic if it can’t lock the mutex.