pub enum ImageRef<'scope> {
Remote(Cow<'scope, Reference>),
LocalTar(Cow<'scope, Path>),
Other(Cow<'scope, str>),
}Expand description
An image ref that could reference a remote registry or a local tarball.
Variants
Implementations
Sourceimpl<'scope> ImageRef<'scope>
impl<'scope> ImageRef<'scope>
pub fn remote_ref(&self) -> Option<&Reference>
pub fn with_platform(&'scope self, platform: Platform) -> Self
Sourcepub fn append_tag(&self, value: &Tag) -> Self
pub fn append_tag(&self, value: &Tag) -> Self
Appends a value to the end of a tag.
If the ref is a tarball, it will append it to the file stem. If it’s other, it will append to the end of the value.